# Data manipulation

We provide out of the box support for easy preprocessing of NLP corpora and helpers to work with datasets in the Pytorch way.

::: slp.data.collators
::: slp.data.corpus
::: slp.data.datasets
::: slp.data.transforms